@@ -5,9 +5,9 @@ trimfill.meta <- function(x, left=NULL, ma.fixed=TRUE,
                           comb.fixed=x$comb.fixed, comb.random=x$comb.random,
                           hakn=x$hakn,
                           method.tau=x$method.tau,
+                          prediction=x$prediction, level.predict=x$level.predict,
                           silent=TRUE, ...){
   
-  
   if (!inherits(x, "meta"))
     stop("Argument 'x' must be an object of class \"meta\"")
   if (inherits(x, "metacum"))
@@ -16,13 +16,14 @@ trimfill.meta <- function(x, left=NULL, ma.fixed=TRUE,
     stop("This function is not usable for an object of class \"metainf\"")
   
   
-  if (length(comb.fixed)==0){
+  if (length(comb.fixed)==0)
     comb.fixed <- TRUE
-  }
   ##
-  if (length(comb.random)==0){
+  if (length(comb.random)==0)
     comb.random <- TRUE
-  }
+  ##
+  if (length(prediction)==0)
+    prediction <- FALSE
   
   
   if (length(level)==0){
@@ -35,15 +36,19 @@ trimfill.meta <- function(x, left=NULL, ma.fixed=TRUE,
       warning("level.comb set to 0.95")
     level.comb <- 0.95
   }
-  
-  if (length(hakn)==0){
-    hakn <- FALSE
-  }
   ##
-  if (length(method.tau)==0){
-    method.tau <- "DL"
+  if (length(level.predict)==0){
+    if (prediction & comb.random)
+      warning("level.predict set to 0.95")
+    level.predict <- 0.95
   }
   
+  if (length(hakn)==0)
+    hakn <- FALSE
+  ##
+  if (length(method.tau)==0)
+    method.tau <- "DL"
+  
   
   estimate.missing <- function(TE, TE.sum, type){
     ##
@@ -105,7 +110,7 @@ trimfill.meta <- function(x, left=NULL, ma.fixed=TRUE,
   k <- length(TE)
   ##
   if (k<=2){
-    warning("Minimal number of three studies for trim-and-fill method: 3")
+    warning("Minimal number of three studies for trim-and-fill method")
     return(invisible(NULL))
   }
   
@@ -114,6 +119,25 @@ trimfill.meta <- function(x, left=NULL, ma.fixed=TRUE,
     stop("type must be either 'L' or 'R'")
   
   
+  ##
+  ## Check for levels of confidence interval
+  ##
+  if (!is.numeric(level) | length(level)!=1)
+    stop("parameter 'level' must be a numeric of length 1")
+  if (level <= 0 | level >= 1)
+    stop("parameter 'level': no valid level for confidence interval")
+  ##
+  if (!is.numeric(level.comb) | length(level.comb)!=1)
+    stop("parameter 'level.comb' must be a numeric of length 1")
+  if (level.comb <= 0 | level.comb >= 1)
+    stop("parameter 'level.comb': no valid level for confidence interval")
+  ##
+  if (!is.numeric(level.predict) | length(level.predict)!=1)
+    stop("parameter 'level.predict' must be a numeric of length 1")
+  if (level.predict <= 0 | level.predict >= 1)
+    stop("parameter 'level.predict': no valid level for confidence interval")
+  
+  
   if (is.null(left))
     left <- as.logical(sign(metabias(TE, seTE, method="linreg", k.min=3)$estimate[1])==1)
   ##
@@ -195,11 +219,13 @@ trimfill.meta <- function(x, left=NULL, ma.fixed=TRUE,
   if (!left)
     m <- metagen(-TE, seTE, studlab=studlab,
                  level=level, level.comb=level.comb,
-                 hakn=hakn, method.tau=method.tau)
+                 hakn=hakn, method.tau=method.tau,
+                 prediction=prediction, level.predict=level.predict)
   else
     m <- metagen(TE, seTE, studlab=studlab,
                  level=level, level.comb=level.comb,
-                 hakn=hakn, method.tau=method.tau)
+                 hakn=hakn, method.tau=method.tau,
+                 prediction=prediction, level.predict=level.predict)
   
   ##
   res <- list(studlab=m$studlab,
@@ -207,11 +233,16 @@ trimfill.meta <- function(x, left=NULL, ma.fixed=TRUE,
               w.fixed=m$w.fixed, w.random=m$w.random,
               TE.fixed=m$TE.fixed, seTE.fixed=m$seTE.fixed,
               TE.random=m$TE.random, seTE.random=m$seTE.random,
+              ##
+              seTE.predict=m$seTE.predict,
+              lower.predict=m$lower.predict,
+              upper.predict=m$upper.predict,
+              level.predict=level.predict,
+              ##
               k=m$k, Q=m$Q, tau=m$tau,
               sm=sm,
               method=m$method,
-              ##paste("Inverse variance method (Trim and fill -",
-              ##      ifelse(ma.fixed, "FE model)", "RE model)")),
+              ##
               call=match.call(),
               left=left,
               ma.fixed=ma.fixed,
@@ -222,6 +253,7 @@ trimfill.meta <- function(x, left=NULL, ma.fixed=TRUE,
               hakn=m$hakn,
               df.hakn=m$df.hakn,
               method.tau=m$method.tau,
+              prediction=prediction,
               k0=sum(trimfill),
               level=level, level.comb=level.comb,
               comb.fixed=comb.fixed, comb.random=comb.random)
